@@ -4,12 +4,27 @@ package Net::ISC::DHCPd::OMAPI;
 
 Net::ISC::DHCPd::OMAPI - Talk to a dhcp server
 
+=head1 DESCRIPTION
+
+This module provides an API to query and possible change the ISC DHCPd
+server. The module use OMAPI (Object Management API) which does not
+require the server to be restarted for changes to apply.
+
+OMAPI is simply a communications mechanism that allows you to manipulate
+objects, which is stored in the dhcpd.leases file.
+
+See subclasses for more information about the different objects you can
+manipulate:
+L<Net::ISC::DHCPd::OMAPI::Failover>,
+L<Net::ISC::DHCPd::OMAPI::Group>,
+L<Net::ISC::DHCPd::OMAPI::Host>,
+and L<Net::ISC::DHCPd::OMAPI::Lease>.
+
 =head1 NOTE
 
- BEGIN {
-   Net::ISC::DHCPd::OMAPI::_DEBUG = sub { 1 }; # to enable debug output
-   use Net::ISC::DHCPd::OMAPI;
- }
+To enable debug output, execute this chunk of code before loading the module:
+
+ BEGIN { Net::ISC::DHCPd::OMAPI::_DEBUG = sub { 1 } }
 
 =cut
 
@@ -24,10 +39,10 @@ use Net::ISC::DHCPd::OMAPI::Lease;
 
 BEGIN {
     *Net::ISC::DHCPd::OMAPI::_DEBUG{'CODE'}
-        or *Net::ISC::DHCPd::OMAPI::_DEBUG = sub { 1 };
+        or *Net::ISC::DHCPd::OMAPI::_DEBUG = sub { 0 };
 }
 
-our $OMSHELL = "omshell";
+our $OMSHELL = 'omshell';
 
 =head1 ATTRIBUTES
 
@@ -103,7 +118,7 @@ has _pid => (
 # fork omshell and return an IO::Pty object
 sub _build__fh  {
     my $self = shift;
-    my $pty  = IO::Pty->new;
+    my $pty = IO::Pty->new;
     my($pid, $slave);
 
     pipe my $READ, my $WRITE or confess $!;
@@ -137,22 +152,22 @@ sub _build__fh  {
         $slave = $pty->slave;
         $slave->set_raw;
 
-        open STDIN,  "<&". $slave->fileno or confess "Reopen STDIN: $!\n";
-        open STDOUT, ">&". $slave->fileno or confess "Reopen STDOUT: $!\n";
-        open STDERR, ">&". $slave->fileno or confess "Reopen STDERR: $!\n";
+        open STDIN,  '<&'. $slave->fileno or confess "Reopen STDIN: $!";
+        open STDOUT, '>&'. $slave->fileno or confess "Reopen STDOUT: $!";
+        open STDERR, '>&'. $slave->fileno or confess "Reopen STDERR: $!";
 
         { exec $OMSHELL } # block prevent warning
         print $WRITE int $!;
-        die "Could not exec $OMSHELL: $!";
+        confess "Could not exec $OMSHELL: $!";
     }
 }
 
 # $self->_cmd($cmd);
 sub _cmd {
     my $self = shift;
-    my $cmd  = shift;
-    my $pty  = $self->_fh;
-    my $out  = q();
+    my $cmd = shift;
+    my $pty = $self->_fh;
+    my $out = q();
     my $end_time;
 
     print STDERR "\$ $cmd\n" if _DEBUG;
@@ -195,11 +210,14 @@ Will open a connection to the dhcp server. Check C<$@> on failure.
 
 sub connect {
     my $self = shift;
+    my @commands = qw/port server/;
     my $buffer;
 
-    $self->errstr("");
+    push @commands, 'key' if($self->key);
 
-    for my $attr (qw/port server key/) {
+    $self->errstr('');
+
+    for my $attr (@commands) {
         $buffer = $self->_cmd(sprintf "%s %s", $attr, $self->$attr);
         last unless(defined $buffer);
     }
@@ -207,7 +225,7 @@ sub connect {
     if($self->errstr) {
         return;
     }
-    unless($buffer = $self->_cmd("connect")) {
+    unless($buffer = $self->_cmd('connect')) {
         return;
     }
     unless($buffer =~ /obj:\s+/) {
@@ -227,7 +245,7 @@ Will disconnect from the server.
 =cut
 
 sub disconnect {
-    my $self    = shift;
+    my $self = shift;
     my $retries = 10;
 
     while($retries--) {
@@ -261,10 +279,10 @@ Example, with C<$type="host">:
 =cut
 
 sub new_object {
-    my $self  = shift;
-    my $type  = shift or return;
-    my %args  = @_;
-    my $class = "Net::ISC::DHCPd::OMAPI::" .ucfirst(lc $type);
+    my $self = shift;
+    my $type = shift or return;
+    my %args = @_;
+    my $class = 'Net::ISC::DHCPd::OMAPI::' .ucfirst(lc $type);
 
     unless($type =~ /^(?:control|failover|group|host|lease)$/i) {
         return;
